@@ -19,7 +19,7 @@ class MindsDBLexer(Lexer):
         # Misc
         SET, START, TRANSACTION, COMMIT, ROLLBACK, ALTER, EXPLAIN,
         ISOLATION, LEVEL, REPEATABLE, READ, WRITE, UNCOMMITTED, COMMITTED,
-        SERIALIZABLE, ONLY, CONVERT,
+        SERIALIZABLE, ONLY, CONVERT, BEGIN,
 
         # Mindsdb special
 
@@ -32,13 +32,14 @@ class MindsDBLexer(Lexer):
 
         # SHOW/DDL Keywords
 
-        SHOW, SCHEMAS, SCHEMA, DATABASES, DATABASE, TABLES, TABLE, FULL,
+        SHOW, SCHEMAS, SCHEMA, DATABASES, DATABASE, TABLES, TABLE, FULL, EXTENDED, PROCESSLIST,
+        MUTEX, CODE, SLAVE, REPLICA, REPLICAS, CHANNEL, TRIGGERS, KEYS, STORAGE, LOGS, BINARY,
+        MASTER, PRIVILEGES, PROFILES, HOSTS, OPEN, INDEXES,
         VARIABLES, SESSION, STATUS,
         GLOBAL, PROCEDURE, FUNCTION, INDEX, WARNINGS,
         ENGINES, CHARSET, COLLATION, PLUGINS, CHARACTER,
         PERSIST, PERSIST_ONLY, DEFAULT,
-        IF_EXISTS,
-
+        IF_EXISTS, COLUMNS, FIELDS,
 
         # SELECT Keywords
         WITH, SELECT, DISTINCT, FROM, WHERE, AS,
@@ -61,7 +62,7 @@ class MindsDBLexer(Lexer):
         # Operators
         PLUS, MINUS, DIVIDE, MODULO,
         EQUALS, NEQUALS, GREATER, GEQ, LESS, LEQ,
-        AND, OR, NOT, IS,
+        AND, OR, NOT, IS, IS_NOT,
         IN, LIKE, CONCAT, BETWEEN, WINDOW, OVER, PARTITION_BY,
 
         # Data types
@@ -114,8 +115,8 @@ class MindsDBLexer(Lexer):
     SERIALIZABLE = r'\bSERIALIZABLE\b'
     ONLY = r'\bONLY\b'
     CONVERT = r'\bCONVERT\b'
-
     DESCRIBE = r'\bDESCRIBE\b'
+    BEGIN = r'\bBEGIN\b'
 
     # SHOW
     SHOW = r'\bSHOW\b'
@@ -144,6 +145,27 @@ class MindsDBLexer(Lexer):
     PERSIST_ONLY = r'\bPERSIST_ONLY\b'
     DEFAULT = r'\bDEFAULT\b'
     IF_EXISTS = r'\bIF[\s]+EXISTS\b'
+    COLUMNS = r'\bCOLUMNS\b'
+    FIELDS = r'\bFIELDS\b'
+    EXTENDED = r'\bEXTENDED\b'
+    PROCESSLIST = r'\bPROCESSLIST\b'
+    MUTEX = r'\bMUTEX\b'
+    CODE = r'\bCODE\b'
+    SLAVE = r'\bSLAVE\b'
+    REPLICA = r'\bREPLICA\b'
+    REPLICAS = r'\bREPLICAS\b'
+    CHANNEL = r'\bCHANNEL\b'
+    TRIGGERS = r'\bTRIGGERS\b'
+    KEYS = r'\bKEYS\b'
+    STORAGE = r'\bSTORAGE\b'
+    LOGS = r'\bLOGS\b'
+    BINARY = r'\bBINARY\b'
+    MASTER = r'\bMASTER\b'
+    PRIVILEGES = r'\bPRIVILEGES\b'
+    PROFILES = r'\bPROFILES\b'
+    HOSTS = r'\bHOSTS\b'
+    OPEN = r'\bOPEN\b'
+    INDEXES = r'\bINDEXES\b'
 
     # SELECT
 
@@ -211,6 +233,7 @@ class MindsDBLexer(Lexer):
     LESS = r'<'
     AND = r'\bAND\b'
     OR = r'\bOR\b'
+    IS_NOT = r'\bIS[\s]+NOT\b'
     NOT = r'\bNOT\b'
     IS = r'\bIS\b'
     LIKE = r'\bLIKE\b'
@@ -232,7 +255,7 @@ class MindsDBLexer(Lexer):
     def ID(self, t):
         return t
 
-    @_(r'\d+\.\d+')
+    @_(r'\d+\.\d*')
     def FLOAT(self, t):
         return t
 
